@@ -72,10 +72,12 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
     opt_inline_css ( false ),
     opt_enclose_pre ( false ),
     opt_char_styles ( false ),
+    opt_page_color(false),
     opt_pretty_symbols ( false ),
     opt_delim_CR (false),
     opt_print_style(false),
     opt_no_trailing_nl(false),
+    opt_keep_injections(false),
     anchorPrefix ( "l" ),
     helpLang ( "en" ),
     encodingName ( "ISO-8859-1" )
@@ -84,14 +86,16 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         S_OPT_ENCLOSE_PRE = 256, S_OPT_FORCE_OUTPUT,
         S_OPT_INLINE_CSS, S_OPT_KW_CASE,
         S_OPT_PRINT_CONFIG, S_OPT_TEST_INPUT, S_OPT_NO_NUMBER_WL,
-        S_OPT_SVG_WIDTH, S_OPT_SVG_HEIGHT, S_OPT_CLASSNAME, S_OPT_RTF_CHAR_STYLES,
+        S_OPT_SVG_WIDTH, S_OPT_SVG_HEIGHT, S_OPT_CLASSNAME,
+        S_OPT_RTF_CHAR_STYLES, S_OPT_RTF_PAGE_COLOR,
         S_OPT_SKIP_UNKNOWN,
         S_OPT_COMPAT_DOC, S_OPT_COMPAT_NODOC, S_OPT_COMPAT_TAB, S_OPT_COMPAT_CSS,
         S_OPT_COMPAT_OUTDIR, S_OPT_COMPAT_FAILSAFE,
         S_OPT_COMPAT_SRCLANG, S_OPT_COMPAT_LINENUM, S_OPT_COMPAT_LINEREF,
         S_OPT_PRETTY_SYMBOLS, S_OPT_EOL_DELIM_CR, S_OPT_START_NESTED,
         S_OPT_PRINT_STYLE, S_OPT_NO_TRAILING_NL, S_OPT_PLUGIN, S_OPT_ABS_CFG_PATH,
-        S_OPT_PLUGIN_READFILE, S_LIST_SCRIPTS
+        S_OPT_PLUGIN_READFILE, S_OPT_PLUGIN_PARAMETER, S_LIST_SCRIPTS,
+        S_OPT_KEEP_INJECTIONS
     };
 
     const Arg_parser::Option options[] = {
@@ -148,6 +152,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         { S_OPT_TEST_INPUT,   OPT_TEST_INPUT,   Arg_parser::no  },
         { S_OPT_NO_NUMBER_WL, OPT_NO_NUMBER_WL, Arg_parser::no  },
         { S_OPT_RTF_CHAR_STYLES, OPT_RTF_CHAR_STYLES, Arg_parser::no  },
+        { S_OPT_RTF_PAGE_COLOR, OPT_RTF_PAGE_COLOR, Arg_parser::no  },
         { S_OPT_SKIP_UNKNOWN, OPT_SKIP_UNKNOWN, Arg_parser::yes },
         { S_OPT_START_NESTED,   OPT_START_NESTED,   Arg_parser::yes },
         { S_OPT_COMPAT_DOC,   OPT_COMPAT_DOC, Arg_parser::no },
@@ -163,8 +168,10 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         { S_OPT_EOL_DELIM_CR,   OPT_EOL_DELIM_CR,   Arg_parser::no },
         { S_OPT_PRINT_STYLE,    OPT_PRINT_STYLE, Arg_parser::no },
         { S_OPT_NO_TRAILING_NL, OPT_NO_TRAILING_NL, Arg_parser::no },
+        { S_OPT_KEEP_INJECTIONS, OPT_KEEP_INJECTIONS, Arg_parser::no },
         { S_OPT_PLUGIN, OPT_PLUGIN, Arg_parser::yes },
         { S_OPT_PLUGIN_READFILE, OPT_PLUGIN_READFILE, Arg_parser::yes },
+        { S_OPT_PLUGIN_PARAMETER, OPT_PLUGIN_PARAMETER, Arg_parser::yes },
         { S_OPT_ABS_CFG_PATH, OPT_ABS_CFG_PATH,  Arg_parser::yes},
         { S_LIST_SCRIPTS, OPT_LIST_SCRIPTS,  Arg_parser::yes},
 
@@ -178,7 +185,7 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         cerr << "Try `highlight --help' for more information.\n";
         exit ( 1 );
     }
-
+    
     int argind = 0;
     for ( ; argind < parser.arguments(); ++argind ) {
         const int code = parser.code ( argind );
@@ -384,14 +391,20 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         case S_OPT_RTF_CHAR_STYLES:
             opt_char_styles=true;
             break;
+        case S_OPT_RTF_PAGE_COLOR:
+             opt_page_color=true;
+            break;
+          
         case S_OPT_SKIP_UNKNOWN:
             skipArg=arg;
             break;
         case S_OPT_PLUGIN:
             userPlugins.push_back(arg);
             break;
+
+        case S_OPT_PLUGIN_PARAMETER:
         case S_OPT_PLUGIN_READFILE:
-            pluginReadFilePath=arg;
+            pluginParameter=arg;
             break;
 
         case S_OPT_PRETTY_SYMBOLS:
@@ -417,6 +430,9 @@ CmdLineOptions::CmdLineOptions ( const int argc, const char *argv[] ) :
         case S_OPT_NO_TRAILING_NL:
             opt_no_trailing_nl = true;
             break;
+        case S_OPT_KEEP_INJECTIONS:
+            opt_keep_injections = true;
+            break;
         case S_OPT_ABS_CFG_PATH:
             if (arg.find(".lang")!=string::npos) {
                 absLangPath=arg;
@@ -731,10 +747,18 @@ bool CmdLineOptions::includeCharStyles() const
 {
     return opt_char_styles;
 }
+bool CmdLineOptions::includePageColor() const
+{
+  return opt_page_color;
+}
 bool CmdLineOptions::disableTrailingNL() const
 {
     return opt_no_trailing_nl;
 }
+bool CmdLineOptions::keepInjections() const
+{
+  return opt_keep_injections;
+}
 const string& CmdLineOptions::getDocumentTitle() const
 {
     return docTitle;
@@ -809,7 +833,7 @@ const string& CmdLineOptions::getAbsLangPath() const
 }
 const string& CmdLineOptions::getPluginReadFilePath() const
 {
-    return pluginReadFilePath;
+    return pluginParameter;
 }
 int CmdLineOptions::getNumberWidth()
 {
