@@ -56,7 +56,7 @@ void printHelp()
     cout<<"                                  <type> = [langs, themes, plugins]\n";
     cout<<"     --plug-in=<script>         execute Lua plug-in script; repeat option to\n";
     cout<<"                                  execute multiple plug-ins\n";
-    cout<<"     --plug-in-read=<path>      set input file for a plug-in (e.g. \"tags\")\n";
+    cout<<"     --plug-in-param=<value>    set plug-in input parameter\n";
     cout<<"     --print-config             print path configuration\n";
     cout<<"     --print-style              print stylesheet only (see --style-outfile)\n";
     cout<<"     --skip=<list>              ignore listed unknown file types\n";
@@ -84,8 +84,8 @@ void printHelp()
     cout<<"                                  horstmann, java, kr, linux, otbs, vtk,\n";
     cout<<"                                  stroustrup, whitesmith, google, pico, lisp]\n";
     cout<<" -I, --include-style            include style definition in output file\n";
-    cout<<" -J, --line-length=<num>        line length before wrapping (see -W, -V)\n";
-    cout<<" -j, --line-number-length=<num> line number width incl. left padding\n";
+    cout<<" -J, --line-length=<num>        line length before wrapping (see -V, -W)\n";
+    cout<<" -j, --line-number-length=<num> line number width incl. left padding (default: 5)\n";
     cout<<" -k, --font=<font>              set font (specific to output format)\n";
     cout<<" -K, --font-size=<num?>         set font size (specific to output format)\n";
     cout<<" -l, --line-numbers             print line numbers in output file\n";
@@ -95,15 +95,16 @@ void printHelp()
     cout<<" -T, --doc-title=<title>        document title\n";
     cout<<" -u, --encoding=<enc>           set output encoding which matches input file\n";
     cout<<"                                  encoding; omit encoding info if set to NONE\n";
-    cout<<" -V, --wrap-simple              wrap long lines without indenting function\n";
-    cout<<"                                  parameters and statements\n";
-    cout<<" -W, --wrap                     wrap long lines\n";
+    cout<<" -V, --wrap-simple              wrap lines after 80 (default) characters w/o\n";
+    cout<<"                                  indenting function parameters and statements\n";
+    cout<<" -W, --wrap                     wrap lines after 80 (default) characters\n";
     cout<<"     --wrap-no-numbers          omit line numbers of wrapped lines\n";
     cout<<"                                  (assumes -l)\n";
     cout<<" -z, --zeroes                   pad line numbers with 0's\n";
+    cout<<"     --delim-cr                 set CR as end-of-line delimiter (MacOS 9)\n";
+    cout<<"     --keep-injections          output plug-in injections in spite of -f\n";
     cout<<"     --kw-case=<case>           change case of case insensitive keywords\n";
     cout<<"                                  <case> =  [upper, lower, capitalize]\n";
-    cout<<"     --delim-cr                 set CR as end-of-line delimiter (MacOS 9)\n";
     cout<<"     --no-trailing-nl           omit trailing newline\n";
     cout<<"\n\n";
     cout<<"(X)HTML output options:\n";
@@ -128,6 +129,7 @@ void printHelp()
     cout<<"\n";
     cout<<"RTF output options:\n";
     cout<<"\n";
+    cout<<"     --page-color               include page color attributes\n";
     cout<<" -x, --page-size=<ps>           set page size \n";
     cout<<"                                  <ps> = [a3, a4, a5, b4, b5, b6, letter]\n";
     cout<<"     --char-styles              include character stylesheets\n";
