@@ -48,8 +48,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "xterm256generator.h"
 #endif
 
-using namespace std;
-
 namespace highlight
 {
 const unsigned int CodeGenerator::NUMBER_BUILTIN_STATES = highlight::KEYWORD;
@@ -121,6 +119,7 @@ CodeGenerator::CodeGenerator ( highlight::OutputType type )
      maskWs ( false ),
      excludeWs ( false ),
      fragmentOutput ( false ),
+     keepInjections( false ),
      showLineNumbers ( false ),
      lineNumberFillZeroes ( false ),
      printNewLines(true),
@@ -244,7 +243,15 @@ bool CodeGenerator::getFragmentCode()
 {
     return fragmentOutput;
 }
+void CodeGenerator::setKeepInjections ( bool flag )
+{
+  keepInjections=flag;
+}
 
+bool CodeGenerator::getKeepInjections()
+{
+  return keepInjections;
+}
 void CodeGenerator::setValidateInput ( bool flag )
 {
     validateInput=flag;
@@ -266,14 +273,14 @@ bool CodeGenerator::getNumberWrappedLines()
     return numberWrappedLines;
 }
 
-void CodeGenerator::setBaseFont ( const string& s )
+void CodeGenerator::setBaseFont ( const string& fontName )
 {
-    baseFont = s;
+    baseFont = fontName;
 }
 
-void CodeGenerator::setBaseFontSize ( const string& s )
+void CodeGenerator::setBaseFontSize ( const string& fontSize)
 {
-    baseFontSize = s ;
+    baseFontSize = fontSize;
 }
 
 void CodeGenerator::setStartingNestedLang(const string &langName)
@@ -287,6 +294,7 @@ const string CodeGenerator::getBaseFont() const
     switch ( outputType ) {
     case HTML:
     case XHTML:
+    case SVG:
         return "'Courier New',monospace";
         break;
     case LATEX:
@@ -295,9 +303,6 @@ const string CodeGenerator::getBaseFont() const
     case TEX:
         return "tt";
         break;
-    case ODTFLAT:
-        return "FreeMono";
-        break;
     default:
         return "Courier New";
     }
@@ -487,7 +492,6 @@ unsigned char CodeGenerator::getInputChar()
 
 State CodeGenerator::getCurrentState (State oldState)
 {
-
     unsigned char c='\0';
 
     if ( token.length() ==0 ) {
@@ -513,6 +517,7 @@ State CodeGenerator::getCurrentState (State oldState)
     if ( !regexGroups.empty() ) {
         if ( regexGroups.count ( lineIndex ) ) {
             token = line.substr ( lineIndex-1, regexGroups[lineIndex].length );
+    
             unsigned int oldIndex= lineIndex;
             if ( regexGroups[oldIndex].length>1 ) lineIndex+= regexGroups[oldIndex].length-1;
 
@@ -543,7 +548,6 @@ State CodeGenerator::validateState(State newState, State oldState, unsigned int
 {
 
     if (currentSyntax->getValidateStateChangeFct()) {
-
         Diluculum::LuaValueList params;
         params.push_back(Diluculum::LuaValue(oldState));
         params.push_back(Diluculum::LuaValue(newState));
@@ -556,7 +560,14 @@ State CodeGenerator::validateState(State newState, State oldState, unsigned int
 
         resultOfHook = res.size()==1;
         if (resultOfHook) {
-            return (State)res[0].asNumber();
+            State validatedState = (State)res[0].asNumber();
+            if ( validatedState== _REJECT){
+                // proceed using only the first character of the token
+                lineIndex -= (token.length() -1);
+                token=token.substr(0, 1); 
+                return oldState;
+            }
+            return validatedState;
         }
     }
     resultOfHook  = false;
@@ -571,28 +582,32 @@ void CodeGenerator::maskString ( ostream& ss, const string & s )
     }
 }
 
-void CodeGenerator::printMaskedToken ( /*bool addMetaInfo,*/ bool flushWhiteSpace,
-        StringTools::KeywordCase tcase )
+
+Diluculum::LuaValueList CodeGenerator::callDecorateFct(const string&token){
+    Diluculum::LuaValueList params;
+    params.push_back(Diluculum::LuaValue(token));
+    params.push_back(Diluculum::LuaValue(currentState));
+    params.push_back(Diluculum::LuaValue(currentKeywordClass));
+
+    return currentSyntax->getLuaState()->call ( *currentSyntax->getDecorateFct(),
+                                               params,"getDecorateFct call")  ;
+}
+
+void CodeGenerator::printMaskedToken (bool flushWhiteSpace, StringTools::KeywordCase tcase )
 {
     if ( flushWhiteSpace )
         flushWs();
-
+    string caseToken = StringTools::change_case ( token, tcase );
     if (currentSyntax->getDecorateFct()) {
-        Diluculum::LuaValueList params;
-        params.push_back(Diluculum::LuaValue(token));
-        params.push_back(Diluculum::LuaValue(currentState));
-        params.push_back(Diluculum::LuaValue(currentKeywordClass));
-
-        Diluculum::LuaValueList res=
-            currentSyntax->getLuaState()->call ( *currentSyntax->getDecorateFct(),
-                    params,"getDecorateFct call")  ;
+        
+      Diluculum::LuaValueList res=callDecorateFct(caseToken);    
         if (res.size()==1) {
             *out<<res[0].asString();
         } else {
-            maskString ( *out, StringTools::change_case ( token, tcase ) );
+            maskString ( *out, caseToken );
         }
     } else {
-        maskString ( *out, StringTools::change_case ( token, tcase ) );
+      maskString ( *out, caseToken );
     }
 
     token.clear();
@@ -748,6 +763,22 @@ bool CodeGenerator::validateInputStream()
            || magic_table[magic_index] == magic_utf8;
 }
 
+void CodeGenerator::printHeader(){
+  if ( ! fragmentOutput ) 
+    *out << getHeader();
+  
+  if ( !fragmentOutput || keepInjections) 
+    *out << currentSyntax->getHeaderInjection();
+}
+
+void CodeGenerator::printFooter(){
+  if ( !fragmentOutput || keepInjections) 
+    *out << currentSyntax->getFooterInjection();
+  
+  if ( ! fragmentOutput )
+    *out << getFooter();
+}
+
 ParseError CodeGenerator::generateFile ( const string &inFileName,
         const string &outFileName )
 {
@@ -781,17 +812,9 @@ ParseError CodeGenerator::generateFile ( const string &inFileName,
         if ( formatter != NULL ) {
             formatter->init ( new astyle::ASStreamIterator ( in ) );
         }
-        if ( ! fragmentOutput ) {
-            *out << getHeader();
-            *out << currentSyntax->getHeaderInjection();
-        }
-
+        printHeader();
         printBody();
-
-        if ( ! fragmentOutput ) {
-            *out << currentSyntax->getFooterInjection();
-            *out << getFooter();
-        }
+        printFooter();
     }
 
     if ( !outFileName.empty() ) {
@@ -824,17 +847,9 @@ string CodeGenerator::generateString ( const string &input )
     if ( formatter != NULL ) {
         formatter->init ( new astyle::ASStreamIterator ( in ) );
     }
-    if ( ! fragmentOutput ) {
-        *out << getHeader();
-        *out << currentSyntax->getHeaderInjection();
-    }
-
+    printHeader();
     printBody();
-
-    if ( ! fragmentOutput ) {
-        *out << currentSyntax->getFooterInjection();
-        *out << getFooter();
-    }
+    printFooter();
 
     string result = static_cast<ostringstream*> ( out )->str();
 
@@ -870,18 +885,10 @@ string CodeGenerator::generateStringFromFile ( const string &inFileName )
     if ( formatter != NULL ) {
         formatter->init ( new astyle::ASStreamIterator ( in ) );
     }
-    if ( ! fragmentOutput ) {
-        *out << getHeader();
-        *out << currentSyntax->getHeaderInjection();
-    }
-
+    printHeader();
     printBody();
-
-    if ( ! fragmentOutput ) {
-        *out << currentSyntax->getFooterInjection();
-        *out << getFooter();
-    }
-
+    printFooter();
+    
     string result = static_cast<ostringstream*> ( out )->str();
 
     delete out;
@@ -1034,6 +1041,14 @@ void CodeGenerator::processRootState()
         }
     } while ( !eof );
     closeTag ( STANDARD );
+    
+    if (currentSyntax->getDecorateLineEndFct()) {
+      Diluculum::LuaValueList res=callDecorateLineFct(false);    
+      if (res.size()==1) {
+        *out << res[0].asString();
+      } 
+    } 
+    
     printNewLines = !noTrailingNewLine;
     *out << getNewLine();
     *out << flush;
@@ -1313,7 +1328,6 @@ bool CodeGenerator::processStringState ( State oldState )
     int openDelimID=currentSyntax->getOpenDelimiterID ( token, myState);
     string openDelim=token;
 
-
     //Raw String by definition:
     bool isRawString=currentSyntax->delimiterIsRawString(openDelimID);
 
@@ -1345,13 +1359,17 @@ bool CodeGenerator::processStringState ( State oldState )
             break;
         case STRING_END:
             if (resultOfHook || currentSyntax->matchesOpenDelimiter (token,  STRING_END, openDelimID)) {
+              if (currentSyntax->assertDelimEqualLength()){
+                exitState= openDelim.length()==token.length();
+              }else {
                 exitState= true;
+              }
                 printMaskedToken();
             }
             break;
         case STRING:
             // if there exist multiple string delimiters, close string if
-            // current delimiters is equal to the opening delimiter
+            // current delimiter is equal to the opening delimiter
             exitState=currentSyntax->delimiterIsDistinct(currentSyntax->getOpenDelimiterID ( token, STRING  ))&&token==openDelim;
             printMaskedToken();
             break;
@@ -1363,7 +1381,6 @@ bool CodeGenerator::processStringState ( State oldState )
                 returnedFromOtherState=true;
             } else {
                 // FIXME not a fix for Python r"""\"""
-                //exitState=(openDelim=="\"" && token=="\\\""); // C# raw string that ends with '\'
                 exitState=token.size()>1 && token[1] == openDelim[0];
                 printMaskedToken();
             }
@@ -1524,12 +1541,38 @@ string CodeGenerator::getNewLine()
     return (printNewLines) ? newLineTag : "";
 }
 
+Diluculum::LuaValueList CodeGenerator::callDecorateLineFct(bool isLineStart){
+       
+   Diluculum::LuaValueList params;
+   params.push_back(Diluculum::LuaValue(lineNumber));
+
+    return currentSyntax->getLuaState()->call ( isLineStart ? 
+           *currentSyntax->getDecorateLineBeginFct(): *currentSyntax->getDecorateLineEndFct(),
+           params,"getDecorateLineFct call")  ;
+  
+}
+
 void CodeGenerator::insertLineNumber ( bool insertNewLine )
 {
     if ( insertNewLine ) {
-        wsBuffer += getNewLine();
+      if (currentSyntax->getDecorateLineEndFct()) {
+        Diluculum::LuaValueList res=callDecorateLineFct(false);    
+        if (res.size()==1) {
+          wsBuffer +=res[0].asString();
+        } 
+      } 
+      
+      wsBuffer += getNewLine();
     }
 
+    
+    if (currentSyntax->getDecorateLineBeginFct()) {
+      Diluculum::LuaValueList res=callDecorateLineFct(true);    
+      if (res.size()==1) {
+        wsBuffer +=res[0].asString();
+      } 
+    } 
+    
     if ( showLineNumbers ) {
         ostringstream os;
         ostringstream numberPrefix;
@@ -1622,7 +1665,7 @@ bool CodeGenerator::initPluginScript(const string& script)
         Diluculum::LuaState ls;
         ls.doFile (script);
         int listIdx=1;
-
+        
         while (ls["Plugins"][listIdx].value() !=Diluculum::Nil) {
 
             // Theme plugins
