@@ -32,8 +32,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "htmlgenerator.h"
 #include "version.h"
 
-using namespace std;
-
 namespace highlight
 {
 
@@ -132,7 +130,13 @@ void HtmlGenerator::printBody()
                  <<";\">";
         }
     }
-    if ( showLineNumbers && orderedList ) *out << "<ol>\n";
+    if ( showLineNumbers && orderedList )
+    {
+        *out << "<ol";
+        if (!cssClassName.empty())
+            *out<<" class=\"" << cssClassName << "\"";
+        *out<< ">\n";
+    }
 
     processRootState();
 
@@ -229,7 +233,7 @@ string HtmlGenerator::getStyleDefinition()
             << ( docStyle.getBgColour().getGreen ( HTML ) )
             << ( docStyle.getBgColour().getBlue ( HTML ) )
             << "; }\n";
-        os << (orderedList ? "li" : "pre");
+        os << (orderedList ? "ol" : "pre");
         if (!cssClassName.empty())
             os<<"."<<cssClassName;
         os << "\t{ color:#"
@@ -300,9 +304,28 @@ string HtmlGenerator::getNewLine()
 
 void HtmlGenerator::insertLineNumber ( bool insertNewLine )
 {
-    if ( insertNewLine ) {
-        wsBuffer += getNewLine();
+  
+   
+  
+    if ( insertNewLine ) {      
+  
+      if (currentSyntax->getDecorateLineEndFct()) {
+        Diluculum::LuaValueList res=callDecorateLineFct(false);    
+        if (res.size()==1) {
+          wsBuffer +=res[0].asString();
+        } 
+      }
+      
+      wsBuffer += getNewLine();
     }
+    
+    if (currentSyntax->getDecorateLineBeginFct()) {
+      Diluculum::LuaValueList res=callDecorateLineFct(true);    
+      if (res.size()==1) {
+        wsBuffer +=res[0].asString();
+      } 
+    } 
+    
     if ( showLineNumbers ) {
         ostringstream numberPrefix;
         int lineNo = lineNumber+lineNumberOffset;
