@@ -2,7 +2,7 @@
                           rtfcode.cpp  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2007 by Andre Simon
+    copyright            : (C) 2002-2016 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -31,15 +31,14 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "rtfgenerator.h"
 
-using namespace std;
-
 namespace highlight
 {
 
 RtfGenerator::RtfGenerator()
     : CodeGenerator ( RTF ),
       pageSize ( "a4" ), // Default: DIN A4
-      addCharStyles ( false )
+      addCharStyles ( false ),
+      addPageColor(false)
 {
     newLineTag = "}\\par\\pard\n\\cbpat1{";
     spacer = " ";
@@ -91,6 +90,16 @@ string  RtfGenerator::getOpenTag ( int styleNumber,const ElementStyle & elem )
 }
 
 
+string  RtfGenerator::getCloseTag ( const ElementStyle &elem )
+{
+    ostringstream s;
+    if ( elem.isBold() ) s << "\\b0 ";
+    if ( elem.isItalic() ) s << "\\i0 ";
+    if ( elem.isUnderline() ) s << "\\ul0 ";
+    s << "}}";
+    return  s.str();
+}
+
 string RtfGenerator::getCharStyle ( int styleNumber,const ElementStyle &elem,
                                     const string&styleName )
 {
@@ -108,17 +117,6 @@ string RtfGenerator::getCharStyle ( int styleNumber,const ElementStyle &elem,
 }
 // {\*\cs2\additive\cf2\f1\fs20\sbasedon222\snext0 HL Default;}
 
-string  RtfGenerator::getCloseTag ( const ElementStyle &elem )
-{
-    ostringstream s;
-    if ( elem.isBold() ) s << "\\b0 ";
-    if ( elem.isItalic() ) s << "\\i0 ";
-    if ( elem.isUnderline() ) s << "\\ul0 ";
-    s << "}}";
-    return  s.str();
-}
-
-
 
 void RtfGenerator::printBody()
 {
@@ -186,6 +184,13 @@ void RtfGenerator::printBody()
         }
         *out << "}}\n";
     }
+    
+    if (addPageColor) {
+      long svVal =  docStyle.getBgColour().getRed() +  
+                    docStyle.getBgColour().getGreen() * 256+ 
+                    docStyle.getBgColour().getBlue() * 256 * 256;
+                    *out<<"\\viewbksp1\\ilfomacatclnup0{\\*\\background{\\shp{{\\sp{\\sn fillColor}{\\sv "<<svVal<<"}}}}}\n";
+    }
 
     *out  << "\\paperw"<< psMap[pageSize].width <<"\\paperh"<< psMap[pageSize].height
           << "\\margl1134\\margr1134\\margt1134\\margb1134\\sectd" // page margins
@@ -359,4 +364,10 @@ void RtfGenerator::setRTFCharStyles ( bool cs )
     addCharStyles = cs;
 }
 
+void RtfGenerator::setRTFPageColor ( bool pc )
+{
+  addPageColor = pc;
+}
+
+
 }
