@@ -29,8 +29,6 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "stringtools.h"
 #include "enums.h"
 
-using namespace std;
-
 namespace highlight
 {
 
@@ -48,32 +46,19 @@ vector<Diluculum::LuaFunction*> SyntaxReader::pluginChunks;
 
 int RegexElement::instanceCnt=0;
 
-int SyntaxReader::luaAddKeyword (lua_State *L)
-{
-    int retVal=0;
-    if (lua_gettop(L)==2) {
-        const char*keyword=lua_tostring(L, 1);
-        unsigned int kwgroupID=lua_tonumber(L, 2);
-        lua_getglobal(L, GLOBAL_INSTANCE_NAME);
-        SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 3));
-        if (*a) {
-            (*a)->addKeyword(kwgroupID, keyword);
-            retVal=1;
-        }
-    }
-    lua_pushboolean(L, retVal);
-    return 1;
-}
 
 SyntaxReader::SyntaxReader() :
     ignoreCase ( false ),
     disableHighlighting ( false ),
     allowNestedComments ( true ),
     reformatCode ( false ),
+    assertEqualLength(false),
     rawStringPrefix(0),
     continuationChar(0),
     validateStateChangeFct(NULL),
     decorateFct(NULL),
+    decorateLineBeginFct(NULL),
+    decorateLineEndFct(NULL),
     luaState(NULL)
 {
 
@@ -86,6 +71,8 @@ SyntaxReader::~SyntaxReader()
     }
     if (validateStateChangeFct) delete validateStateChangeFct;
     if (decorateFct) delete decorateFct;
+    if (decorateLineBeginFct) delete decorateLineBeginFct;
+    if (decorateLineEndFct) delete decorateLineEndFct;
     if (luaState) delete luaState;
     for (unsigned int i=0; i<pluginChunks.size(); i++) {
         delete pluginChunks[i];
@@ -93,49 +80,13 @@ SyntaxReader::~SyntaxReader()
     pluginChunks.clear();
 }
 
-int SyntaxReader::isKeyword ( const string &s )
-{
-    return ( s.length() && keywords.count ( s ) ) ? keywords[s] : 0;
-}
-
-void SyntaxReader::restoreLangEndDelim(const string& langPath)
-{
-    //TODO exitDelimiters be left static?
-    if ( !langPath.empty()&& exitDelimiters.count(langPath) ) {
-        regex.insert (regex.begin(),1, new RegexElement ( EMBEDDED_CODE_END,EMBEDDED_CODE_END, exitDelimiters[langPath] ) );
-    }
-}
-
-unsigned int SyntaxReader::generateNewKWClass ( const string& newClassName )
-{
-    unsigned int newClassID=0;
-    bool found=false;
-    while (!keywordClasses.empty() && newClassID<keywordClasses.size() && !found ) {
-        found = ( newClassName==keywordClasses.at(newClassID++) );
-    }
-    if ( !found ) {
-        newClassID++;
-        keywordClasses.push_back ( newClassName );
-    }
-
-    return newClassID;
-}
-
-
-bool SyntaxReader::readFlag(const Diluculum::LuaVariable& var)
-{
-    if (var.value()==Diluculum::Nil) return false;
-    return var.value().asBoolean();
-}
-
-
-void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefPath, const string& pluginReadFilePath, OutputType type )
+void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefPath, const string& pluginParameter, OutputType type )
 {
     // initialize Lua state with variables which can be used within scripts
     string::size_type Pos = langDefPath.find_last_of ( Platform::pathSeparator );
     ls["HL_LANG_DIR"] =langDefPath.substr ( 0, Pos+1 );
 
-    ls["HL_INPUT_FILE"] = pluginReadFilePath;
+    ls["HL_INPUT_FILE"] = ls["HL_PLUGIN_PARAM"] = pluginParameter;
     ls["HL_OUTPUT"] = type;
 
     ls["Identifiers"]=REGEX_IDENTIFIER;
@@ -167,6 +118,7 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_IDENTIFIER_END"]=IDENTIFIER_END;
     ls["HL_INTERPOLATION_END"]=STRING_INTERPOLATION_END;
     ls["HL_UNKNOWN"]=_UNKNOWN;
+    ls["HL_REJECT"]=_REJECT;
     ls["HL_FORMAT_HTML"]=HTML;
     ls["HL_FORMAT_XHTML"]=XHTML;
     ls["HL_FORMAT_TEX"]=TEX;
@@ -181,17 +133,9 @@ void  SyntaxReader::initLuaState(Diluculum::LuaState& ls, const string& langDefP
     ls["HL_FORMAT_ODT"]=ODTFLAT;
 }
 
-
-void SyntaxReader::addKeyword(unsigned int groupID, const string& kw)
-{
-    if (!isKeyword ( kw )) {
-        keywords.insert ( make_pair (kw, groupID ) );
-    }
-}
-
 LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginReadFilePath, OutputType outputType, bool clear )
 {
-
+  
     currentPath=langDefPath;
     disableHighlighting=false;
 
@@ -286,7 +230,8 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
                     delimIds2[closeDelimId]=openDelimId;
 
                 } else {
-                    regex.push_back ( new RegexElement ( SL_COMMENT, SL_COMMENT_END, StringTools::trim(ls["Comments"][listIdx]["Delimiter"][1].value().asString()), 0, -1 ) );
+                    regex.push_back ( new RegexElement ( SL_COMMENT, SL_COMMENT_END, 
+                                                         StringTools::trim(ls["Comments"][listIdx]["Delimiter"][1].value().asString()), 0, -1 ) );
                 }
                 ++listIdx;
             }
@@ -315,7 +260,8 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
                 regex.push_back (elem );
             }
             if (ls["Strings"]["Interpolation"].value()!=Diluculum::Nil) {
-                RegexElement* elem=new RegexElement ( STRING_INTERPOLATION, STRING_INTERPOLATION_END, StringTools::trim( ls["Strings"]["Interpolation"].value().asString()), 0, -1 );
+                RegexElement* elem=new RegexElement ( STRING_INTERPOLATION, STRING_INTERPOLATION_END, 
+                                                      StringTools::trim( ls["Strings"]["Interpolation"].value().asString()), 0, -1 );
                 regex.push_back (elem );
             }
 
@@ -343,12 +289,13 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
                     if (ls["Strings"]["DelimiterPairs"][listIdx]["Raw"].value()!=Diluculum::Nil) {
                         rawStringOpenDelims[openDelimId]=ls["Strings"]["DelimiterPairs"][listIdx]["Raw"].value().asBoolean();
                     }
-
                     ++listIdx;
                 }
             }
+            
+            assertEqualLength=readFlag(ls["Strings"]["AssertEqualLength"]);
 
-            string  escRegex=(ls["Strings"]["Escape"].value()==Diluculum::Nil)?REGEX_ESCSEQ:ls["Strings"]["Escape"].value().asString();
+            string escRegex=(ls["Strings"]["Escape"].value()==Diluculum::Nil)?REGEX_ESCSEQ:ls["Strings"]["Escape"].value().asString();
             regex.push_back ( new RegexElement ( ESC_CHAR,ESC_CHAR_END, StringTools::trim(escRegex), 0, -1 ) );
         }
 
@@ -379,7 +326,6 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
 
                 ++listIdx;
             }
-
         }
 
         if (globals.count("HeaderInjection")) {
@@ -397,7 +343,13 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
         if (globals.count("Decorate")) {
             decorateFct=new Diluculum::LuaFunction(ls["Decorate"].value().asFunction());
         }
-
+        if (globals.count("DecorateLineBegin")) {
+            decorateLineBeginFct=new Diluculum::LuaFunction(ls["DecorateLineBegin"].value().asFunction());
+        }
+        if (globals.count("DecorateLineEnd")) {
+            decorateLineEndFct=new Diluculum::LuaFunction(ls["DecorateLineEnd"].value().asFunction());
+        }
+        
     } catch (Diluculum::LuaError err) {
         luaErrorMsg = string(err.what());
         return LOAD_FAILED_LUA;
@@ -405,6 +357,68 @@ LoadResult SyntaxReader::load ( const string& langDefPath, const string& pluginR
     return LOAD_OK;
 }
 
+
+void SyntaxReader::addKeyword(unsigned int groupID, const string& kw)
+{
+    if (!isKeyword ( kw )) {
+        keywords.insert ( make_pair (kw, groupID ) );
+    }
+}
+
+int SyntaxReader::isKeyword ( const string &s )
+{
+    return ( s.length() && keywords.count ( s ) ) ? keywords[s] : 0;
+}
+
+int SyntaxReader::luaAddKeyword (lua_State *L)
+{
+    int retVal=0;
+    if (lua_gettop(L)==2) {
+        const char*keyword=lua_tostring(L, 1);
+        unsigned int kwgroupID=lua_tonumber(L, 2);
+        lua_getglobal(L, GLOBAL_INSTANCE_NAME);
+        SyntaxReader **a=reinterpret_cast<SyntaxReader **>(lua_touserdata(L, 3));
+        if (*a) {
+            (*a)->addKeyword(kwgroupID, keyword);
+            retVal=1;
+        }
+    }
+    lua_pushboolean(L, retVal);
+    return 1;
+}
+
+
+void SyntaxReader::restoreLangEndDelim(const string& langPath)
+{
+    //TODO exitDelimiters be left static?
+    if ( !langPath.empty()&& exitDelimiters.count(langPath) ) {
+        regex.insert (regex.begin(),1, new RegexElement ( EMBEDDED_CODE_END,EMBEDDED_CODE_END, exitDelimiters[langPath] ) );
+    }
+}
+
+unsigned int SyntaxReader::generateNewKWClass ( const string& newClassName )
+{
+    unsigned int newClassID=0;
+    bool found=false;
+    while (!keywordClasses.empty() && newClassID<keywordClasses.size() && !found ) {
+        found = ( newClassName==keywordClasses.at(newClassID++) );
+    }
+    if ( !found ) {
+        newClassID++;
+        keywordClasses.push_back ( newClassName );
+    }
+
+    return newClassID;
+}
+
+
+bool SyntaxReader::readFlag(const Diluculum::LuaVariable& var)
+{
+    if (var.value()==Diluculum::Nil) return false;
+    return var.value().asBoolean();
+}
+
+
 string SyntaxReader::getNewPath(const string& lang)
 {
     string::size_type Pos = currentPath.find_last_of ( Platform::pathSeparator );
