@@ -141,6 +141,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     readSettings();
     plausibility();
+    statusBar()->showMessage(tr("Always at your service"), 2500);
 }
 
 MainWindow::~MainWindow()
@@ -189,15 +190,6 @@ void MainWindow::addToView(const QStringList& list, QListWidget* listWidget, con
     }
 }
 
-
-void MainWindow::on_pbClearSelection_clicked()
-{
-    QList<QListWidgetItem *> selectedItems = ui->lvInputFiles->selectedItems();
-    for (int i = 0; i < selectedItems.size(); ++i) {
-        delete selectedItems.at(i);
-    }
-}
-
 void MainWindow::on_pbOutputDest_clicked()
 {
     QFileDialog dialog(this, tr("Select destination directory"), "");
@@ -252,6 +244,8 @@ void MainWindow::writeSettings()
                       ui->cbEncoding->isChecked());
     settings.setValue(ui->cbFragment->property(name).toString(),
                       ui->cbFragment->isChecked());
+    settings.setValue(ui->cbKeepInjections->property(name).toString(),
+                      ui->cbKeepInjections->isChecked());
     settings.setValue(ui->cbHTMLAnchors->property(name).toString(),
                       ui->cbHTMLAnchors->isChecked());
 
@@ -283,6 +277,8 @@ void MainWindow::writeSettings()
                       ui->cbReformat->isChecked());
     settings.setValue(ui->cbRTFCharStyles->property(name).toString(),
                       ui->cbRTFCharStyles->isChecked());
+    settings.setValue(ui->cbRTFPageColor->property(name).toString(),
+                      ui->cbRTFPageColor->isChecked());
     settings.setValue(ui->cbWrapping->property(name).toString(),
                       ui->cbWrapping->isChecked());
     settings.setValue(ui->cbValidateInput->property(name).toString(),
@@ -388,6 +384,7 @@ void MainWindow::readSettings()
     ui->cbAdvWrapping->setChecked(settings.value(ui->cbAdvWrapping->property(name).toString()).toBool());
     ui->cbEncoding->setChecked(settings.value(ui->cbEncoding->property(name).toString()).toBool());
     ui->cbFragment->setChecked(settings.value(ui->cbFragment->property(name).toString()).toBool());
+    ui->cbKeepInjections->setChecked(settings.value(ui->cbKeepInjections->property(name).toString()).toBool());
     ui->cbHTMLAnchors->setChecked(settings.value(ui->cbHTMLAnchors->property(name).toString()).toBool());
     ui->cbHTMLEmbedStyle->setChecked(settings.value(ui->cbHTMLEmbedStyle->property(name).toString()).toBool());
     ui->cbHTMLEnclosePreTags->setChecked(settings.value(ui->cbHTMLEnclosePreTags->property(name).toString()).toBool());
@@ -404,6 +401,7 @@ void MainWindow::readSettings()
     ui->cbPadZeroes->setChecked(settings.value(ui->cbPadZeroes->property(name).toString()).toBool());
     ui->cbReformat->setChecked(settings.value(ui->cbReformat->property(name).toString()).toBool());
     ui->cbRTFCharStyles->setChecked(settings.value(ui->cbRTFCharStyles->property(name).toString()).toBool());
+    ui->cbRTFPageColor->setChecked(settings.value(ui->cbRTFPageColor->property(name).toString()).toBool());
     ui->cbWrapping->setChecked(settings.value(ui->cbWrapping->property(name).toString()).toBool());
     ui->cbValidateInput->setChecked(settings.value(ui->cbValidateInput->property(name).toString()).toBool());
 
@@ -531,7 +529,7 @@ void MainWindow::on_action_About_Highlight_triggered()
     QMessageBox::about( this, "About Highlight",
                         QString("Highlight is a code to formatted text converter.\n\n"
                                 "Highlight GUI %1\n"
-                                "(C) 2002-2015 Andre Simon <andre.simon1 at gmx.de>\n\n"
+                                "(C) 2002-2016 Andre Simon <andre.simon1 at gmx.de>\n\n"
                                 "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
                                 "(C) 2006-2014 Jim Pattee <jimp03 at email.com>\n\n"
                                 "Diluculum Lua wrapper\n"
@@ -633,9 +631,10 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
             generator->setIncludeStyle(embedStyle->isChecked());
 
         generator->setFragmentCode(ui->cbFragment->isChecked());
+        generator->setKeepInjections(ui->cbKeepInjections->isChecked());
 
         generator->setHTMLAttachAnchors(ui->cbHTMLAnchors->isChecked());
-        generator->setHTMLOrderedList(ui->cbHTMLOrderedList->isChecked());
+        generator->setHTMLOrderedList(ui->cbIncLineNo->isChecked() && ui->cbHTMLOrderedList->isChecked());
         generator->setHTMLInlineCSS(ui->cbHTMLInlineCSS->isChecked() && ui->cbHTMLInlineCSS->isEnabled());
         generator->setHTMLEnclosePreTag(ui->cbHTMLEnclosePreTags->isChecked());
 
@@ -648,6 +647,7 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
 
         generator->setRTFPageSize(ui->comboRTFPageSize->currentText().toLower().toStdString());
         generator->setRTFCharStyles(ui->cbRTFCharStyles->isChecked());
+        generator->setRTFPageColor(ui->cbRTFPageColor->isChecked());
 
         generator->setSVGSize(ui->leSVGWidth->text().toStdString(), ui->leSVGHeight->text().toStdString());
     }
@@ -736,11 +736,19 @@ void MainWindow::on_pbStartConversion_clicked()
 
     if (!ui->lvInputFiles->count()) return;
 
-    if (!ui->cbWrite2Src->isChecked() && !QDir(ui->leOutputDest->text()).exists()) {
-        QMessageBox::warning(this, tr("Output error"), tr("Output directory does not exist!"));
-        ui->leOutputDest->setFocus();
-        return;
+    if (!ui->cbWrite2Src->isChecked() ) {
+
+        if (ui->leOutputDest->text().isEmpty()){
+            ui->pbOutputDest->click();
+            return;
+        }
+        if (!QDir(ui->leOutputDest->text()).exists()){
+            QMessageBox::warning(this, tr("Output error"), tr("Output directory does not exist!"));
+            ui->leOutputDest->setFocus();
+            return;
+        }
     }
+
     highlight::OutputType outType = getOutputType();
     QCheckBox* cbEmbed=NULL;
     QLineEdit* leStyleFile=NULL;
@@ -795,6 +803,8 @@ void MainWindow::on_pbStartConversion_clicked()
         inFilePath =  ui->lvInputFiles->item(i)->data(Qt::UserRole).toString();
         currentFile = inFilePath.toStdString();
 
+          statusBar()->showMessage(tr("Processing %1 (%2/%3)").arg(inFilePath).arg(i+1).arg(ui->lvInputFiles->count()));
+
 #ifdef DATA_DIR
         langDefPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(DATA_DIR).arg(
                 QString::fromStdString(getFileType(getFileSuffix(currentFile), currentFile))));
@@ -821,7 +831,7 @@ void MainWindow::on_pbStartConversion_clicked()
                 reformatErrors.append(inFilePath);
             }
 
-            inFileName = QFileInfo(inFilePath).fileName();
+            inFileName = ui->lvInputFiles->item(i)->text(); // QFileInfo(inFilePath).fileName();
 
             if (ui->cbWrite2Src->isChecked()) {
                 outfileName = currentFile;
@@ -838,8 +848,7 @@ void MainWindow::on_pbStartConversion_clicked()
                 outFileInfo.setFile(ui->leOutputDest->text(),fName);
                 outfileName = outFileInfo.absoluteFilePath().toStdString();
             }
-            outfileName +=  getOutFileSuffix().toStdString();;
-
+            outfileName +=  getOutFileSuffix().toStdString();
 
             if (ui->cbHTMLFileNameAnchor->isChecked()) {
                 generator->setHTMLAnchorPrefix(inFileName.toStdString());
@@ -896,16 +905,12 @@ void MainWindow::on_pbStartConversion_clicked()
         if (report.removeInputErrorFiles()) {
 
             for (int i=0; i<inputErrors.count(); i++) {
-
-
                 for (int j = 0 ; j < ui->lvInputFiles->count(); ++j) {
                     if (ui->lvInputFiles->item(j)->data(Qt::UserRole).toString()==inputErrors.at(i)) {
                         delete ui->lvInputFiles->item(j);
                         break;
                     }
                 }
-
-
             }
         }
     }
@@ -1008,6 +1013,7 @@ void MainWindow::plausibility()
     ui->sbLineNoStart->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLIndex->setEnabled(!ui->cbWrite2Src->isChecked());
     ui->cbHTMLEnclosePreTags->setEnabled(ui->cbFragment->isChecked());
+    ui->cbKeepInjections->setEnabled(ui->cbFragment->isChecked());
     ui->cbHTMLAnchors->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLFileNameAnchor->setEnabled(ui->cbIncLineNo->isChecked());
     ui->cbHTMLOrderedList->setEnabled(ui->cbIncLineNo->isChecked());
@@ -1036,7 +1042,6 @@ void MainWindow::plausibility()
         break;
     }
     ui->tabWidgetOptions->setTabText(1, tr("%1 options").arg(ui->comboFormat->currentText() ));
-    //ui->tabWidget->setTabText(1, tr("%1 options").arg(ui->comboFormat->currentText() ));
 }
 
 void MainWindow::updatePreview()
@@ -1231,12 +1236,21 @@ void MainWindow::on_pbSelectPlugin_clicked()
 
 void MainWindow::on_pbClearSelPlugin_clicked()
 {
+
     QList<QListWidgetItem *> selectedItems = ui->lvPluginScripts->selectedItems();
     for (int i = 0; i < selectedItems.size(); ++i) {
         delete selectedItems.at(i);
     }
 }
 
+void MainWindow::on_pbClearSelection_clicked()
+{
+    QList<QListWidgetItem *> selectedItems = ui->lvInputFiles->selectedItems();
+    for (int i = 0; i < selectedItems.size(); ++i) {
+        delete selectedItems.at(i);
+    }
+}
+
 void MainWindow::on_pbClearAll_clicked()
 {
     ui->lvInputFiles->clear();
@@ -1252,7 +1266,6 @@ void MainWindow::on_actionVisit_website_triggered()
     QDesktopServices::openUrl(QUrl("http://www.andre-simon.de/"));
 }
 
-
 void MainWindow::on_actionDock_floating_panels_toggled(bool arg1)
 {
     ui->dockWidget->setFloating(arg1);
@@ -1265,10 +1278,12 @@ void MainWindow::on_pbPluginReadFilePath_clicked()
 
 void MainWindow::on_lvPluginScripts_currentRowChanged(int currentRow)
 {
+    if ( !ui->lvPluginScripts->item(currentRow)) return; // Removing item?
     try {
         Diluculum::LuaState ls;
         ls.doFile ( ui->lvPluginScripts->item(currentRow)->data(Qt::UserRole).toString().toStdString());
         ui->lblPluginDescription->setText(QString::fromStdString(ls["Description"].value().asString()));
+        statusBar()->showMessage(tr("Some plug-in effects may not be visible in the preview."));
     } catch (Diluculum::LuaError err) {
         QMessageBox::warning(this, "Plug-In error", QString::fromStdString( err.what()));
     }
